ProSHADE: src/proshade/ProSHADE_exceptions.hpp Source File

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_exceptions.hpp
Go to the documentation of this file.
1
23 //==================================================== ProSHADE
24 #include "ProSHADE_precomputedValues.hpp"
25
26 //==================================================== Overinclusion protection
27 #ifndef __PROSHADE_EXCEPTIONS__
28 #define __PROSHADE_EXCEPTIONS__
29
36 class ProSHADE_exception : public std::runtime_error
37 {
38 std::string errc;
39 std::string file;
40 unsigned int line;
41 std::string func;
42 std::string info;
43
44 public:
45 ProSHADE_exception ( const char* msg, std::string errc_, std::string file_, unsigned int line_, std::string func_, std::string info_): std::runtime_error ( msg )
46 {
47 this->errc = errc_;
48 this->file = file_;
49 this->line = line_;
50 this->func = func_;
51 this->info = info_;
52 }
53 ~ProSHADE_exception ( ) throw ( ) { }
54
55 std::string get_errc ( void ) const { return errc; }
56 std::string get_file ( void ) const { return file; }
57 unsigned int get_line ( void ) const { return line; }
58 std::string get_func ( void ) const { return func; }
59 std::string get_info ( void ) const { return info; }
60 };
61
62 #endif
ProSHADE_exception
This class is the representation of ProSHADE exception.
Definition: ProSHADE_exceptions.hpp:37